%define gecko_version 1.9

Name: libproxy
Version: 0.2.3
Release: alt1.1
Summary: A library handling all the details of proxy configuration

Group: System/Libraries
License: LGPLv2+
Url: http://code.google.com/p/libproxy/

Source: http://libproxy.googlecode.com/files/libproxy-%version.tar.gz
# Fedora patch
Patch: libproxy-0.2.3-dbus.patch

# Virtual Provides - We need either mozjs or WebKit
#Requires: %name-pac >= %version

BuildRequires: python-devel
# gnome
BuildRequires: libGConf2-devel
# xulrunner
BuildRequires: xulrunner-devel >= %gecko_version
# NetworkManager
BuildRequires: NetworkManager-devel
BuildRequires: libdbus-devel
# webkit (gtk)
BuildRequires: libwebkit-gtk-devel
# kde
BuildRequires: libXmu-devel
BuildRequires: libX11-devel

%description
libproxy offers the following features:

    * extremely small core footprint (< 35K)
    * no external dependencies within libproxy core
      (libproxy plugins may have dependencies)
    * only 3 functions in the stable external API
    * dynamic adjustment to changing network topology
    * a standard way of dealing with proxy settings across all scenarios
    * a sublime sense of joy and accomplishment

Non-default rpmbuild options:
--with webkit:           Enable WebKit-gtk support

%package tools
Summary: Tools to test %name
Group: Networking/Other
Requires: %name = %version-%release

%description tools
The %name-tools package contains the programs to test %name

%package -n python-module-%name
Summary: Python bindings for %name
Group: Development/Python
Requires: %name = %version-%release

%description -n python-module-%name
This package contains the python binding for %name

%package gnome
Summary: Plugin for %name and gnome
Group: System/Libraries
Requires: %name = %version-%release

%description gnome
The %name-gnome package contains the %name plugin for gnome.

%package kde
Summary: Plugin for %name and kde
Group: System/Libraries
Requires: %name = %version-%release

%description kde
The %name-kde package contains the %name plugin for kde.

%package mozjs
Summary: The %name plugin for xulrunner
Group: System/Libraries
Requires: %name = %version-%release
Provides: %name-pac = %version-%release

%description mozjs
This package contains the %name plugin for xulrunner.

%package webkit
Summary: Plugin for %name and webkit
Group: System/Libraries
Requires: %name = %version-%release
Provides: %name-pac = %version-%release

%description webkit
The %name-webkit package contains the %name plugin for
WebKit.

%package devel
Summary: Development files for %name
Group: Development/C
Requires: %name = %version-%release

%description devel
The %name-devel package contains libraries and header files for
developing applications that use %name.

%prep
%setup -q
%patch0 -p1 -b .dbus
touch -r configure.dbus configure
touch -r configure.ac.dbus configure.ac

subst 's/\(libproxy_la_LDFLAGS = -lm\)/\1 -ldl/' src/lib/Makefile*

%build
# to avoid mozilla-js bug
export mozjs_CFLAGS="`pkg-config --cflags mozilla-js` -I//usr/include/xulrunner/unstable"
%configure --includedir=%_includedir/libproxy \
	--disable-static \
	--with-python

%make_build

%install
%make install DESTDIR=%buildroot INSTALL="install -p"
find %buildroot -name '*.la' -exec rm -f {} ';'

%files
%_libdir/*.so.*
%dir %_libdir/%name
%dir %_libdir/%name/%version
%dir %_libdir/%name/%version/plugins
%_libdir/%name/%version/plugins/envvar.so
%_libdir/%name/%version/plugins/file.so
%_libdir/%name/%version/plugins/networkmanager.so
%doc AUTHORS README

%files tools
%_bindir/proxy

%files -n python-module-%name
%python_sitelibdir/*

%files gnome
%_libdir/%name/%version/plugins/gnome.so

%files kde
%_libdir/%name/%version/plugins/kde.so

%files mozjs
%_libdir/%name/%version/plugins/mozjs.so

%files webkit
%_libdir/%name/%version/plugins/webkit.so

%files devel
%_includedir/*
%_libdir/*.so
%_libdir/pkgconfig/libproxy-1.0.pc

%changelog
* Fri Apr 10 2009 Alexey Shabalin <shaba@altlinux.ru> 0.2.3-alt1.1
- rebuild with webkit-1.1.4

* Tue Feb 03 2009 Yuri N. Sedunov <aris@altlinux.org> 0.2.3-alt1
- adapted for Sisyphus

* Thu Jan 22 2009 kwizart < kwizart at gmail.com > - 0.2.3-8
- Merge NetworkManager module into the main libproxy package
- Main Requires the -python and -bin subpackage
 (splitted for multilibs compliance).

* Fri Oct 24 2008 kwizart < kwizart at gmail.com > - 0.2.3-7
- Disable Gnome/KDE default support via builtin modules.
 (it needs to be integrated via Gconf2/neon instead).

* Tue Oct 21 2008 kwizart < kwizart at gmail.com > - 0.2.3-6
- Disable Obsoletes.
- Requires ev instead of evr for optionnals sub-packages.

* Tue Oct 21 2008 kwizart < kwizart at gmail.com > - 0.2.3-5
- Use conditionals build.

* Mon Sep 15 2008 kwizart < kwizart at gmail.com > - 0.2.3-4
- Remove plugin- in the name of the packages

* Mon Aug  4 2008 kwizart < kwizart at gmail.com > - 0.2.3-3
- Move proxy.h to libproxy/proxy.h
  This will prevent it to be included in the default include path
- Split main to libs and util and use libproxy to install all

* Mon Aug  4 2008 kwizart < kwizart at gmail.com > - 0.2.3-2
- Rename binding-python to python
- Add Requires: gecko-libs >= %%{gecko_version}
- Fix some descriptions
- Add plugin-webkit package

* Fri Jul 11 2008 kwizart < kwizart at gmail.com > - 0.2.3-1
- Convert to Fedora spec

* Fri Jun 6 2008 - dominique-rpm@leuenberger.net
- Updated to version 0.2.3
* Wed Jun 4 2008 - dominique-rpm@leuenberger.net
- Extended spec file to build all available plugins
* Tue Jun 3 2008 - dominique-rpm@leuenberger.net
- Initial spec file for Version 0.2.2

